Crate libcrux_blake2

Crate libcrux_blake2 

Structs

Blake2b
A hasher struct for the Blake2b (optionally keyed) hash function.
Blake2bBuilder
A builder for Blake2b. T determines whether
Blake2bHash
A struct that implements libcrux_traits::digest traits.
Blake2s
A hasher struct for the Blake2s (optionally keyed) hash function.
Blake2sBuilder
A builder for Blake2s. T determines whether
Blake2sHash
A struct that implements libcrux_traits::digest traits.
LengthBounds
Type that is used to bound the implementations to valid key and output lengths.

Enums

Error
Indicates an error has occurred

Traits

SupportsKeyLen
A marker trait indicating whether the hash supports keys of length LEN. This trait is sealed to protect the soundness of the compile time bounds checks.
SupportsOutLen
A marker trait indicating whether the hash supports outputs of length LEN. This trait is sealed to protect the soundness of the compile time bounds checks.

Type Aliases

Blake2bHasher
A hasher for Blake2bHash.
Blake2sHasher
A hasher for Blake2sHash.