Blake2b

Struct Blake2b 

pub struct Blake2b<T> { /* private fields */ }
A hasher struct for the Blake2b (optionally keyed) hash function.

Implementations

Source

impl<T> Blake2b<T>

pub fn update(&mut self, chunk: &[u8]) -> Result<(), Error>

Updates the hash state by adding the bytes from chunk to the hashed data.

Source

impl<const KEY_LEN: usize> Blake2b<ConstKeyLen<KEY_LEN>>

pub fn finalize(&self, dst: &mut [u8]) -> Result<usize, Error>

Compute the hash for the current hash state and write it to dst.

Returns a Result that contains the length of the digest on success.

Source

impl Blake2b<Dynamic>

pub fn finalize(&self, dst: &mut [u8]) -> Result<usize, Error>

Compute the hash for the current hash state and write it to dst.

Returns a Result that contains the length of the digest on success.

Source

impl<const KEY_LEN: usize, const OUT_LEN: usize> Blake2b<ConstKeyLenConstDigestLen<KEY_LEN, OUT_LEN>>

pub fn finalize(&self, dst: &mut [u8; OUT_LEN])

Compute the hash for the current hash state and write it to dst.

Source

impl<const OUT_LEN: usize> Blake2b<ConstDigestLen<OUT_LEN>>

pub fn finalize(&self, dst: &mut [u8; OUT_LEN])

Compute the hash for the current hash state and write it to dst.

Source

impl<const KEY_LEN: usize, const OUT_LEN: usize> Blake2b<ConstKeyLenConstDigestLen<KEY_LEN, OUT_LEN>>

pub fn reset_with_key(&mut self, key: &[u8; KEY_LEN])

Reset the hash state and update the key to the contents of key.

Source

impl<const KEY_LEN: usize> Blake2b<ConstKeyLen<KEY_LEN>>

pub fn reset_with_key(&mut self, key: &[u8; KEY_LEN])

Reset the hash state and update the key to the contents of key.

Source

impl<const OUT_LEN: usize> Blake2b<ConstDigestLen<OUT_LEN>>

pub fn reset_with_key(&mut self, key: &[u8]) -> Result<(), Error>

Reset the hash state and update the key to the contents of key.

Source

impl Blake2b<Dynamic>

pub fn reset_with_key(&mut self, key: &[u8]) -> Result<(), Error>

Reset the hash state and update the key to the contents of key.

Source

impl Blake2b<ConstKeyLen<0>>

pub fn reset(&mut self)

Reset the hash state.

Source

impl<const OUT_LEN: usize> Blake2b<ConstKeyLenConstDigestLen<0, OUT_LEN>>

pub fn reset(&mut self)

Reset the hash state.

Source

impl<const OUT_LEN: usize> Blake2b<ConstDigestLen<OUT_LEN>>

pub fn reset(&mut self) -> Result<(), Error>

Reset the hash state.

Source

impl Blake2b<Dynamic>

pub fn reset(&mut self) -> Result<(), Error>

Reset the hash state.