Structs
- Blake2b
- A hasher struct for the Blake2b (optionally keyed) hash function.
- Blake2b
Builder - A builder for
Blake2b.Tdetermines whether - Blake2b
Hash - A struct that implements
libcrux_traits::digesttraits. - Blake2s
- A hasher struct for the Blake2s (optionally keyed) hash function.
- Blake2s
Builder - A builder for
Blake2s.Tdetermines whether - Blake2s
Hash - A struct that implements
libcrux_traits::digesttraits. - Length
Bounds - Type that is used to bound the implementations to valid key and output lengths.
Enums
- Error
- Indicates an error has occurred
Traits
- Supports
KeyLen - A marker trait indicating whether the hash supports keys of length LEN. This trait is sealed to protect the soundness of the compile time bounds checks.
- Supports
OutLen - A marker trait indicating whether the hash supports outputs of length LEN. This trait is sealed to protect the soundness of the compile time bounds checks.
Type Aliases
- Blake2b
Hasher - A hasher for
Blake2bHash. - Blake2s
Hasher - A hasher for
Blake2sHash.