pub struct Blake2b<T> { /* private fields */ }Expand description
A hasher struct for the Blake2b (optionally keyed) hash function.
Implementations
Sourceimpl<const KEY_LEN: usize, const OUT_LEN: usize> Blake2b<ConstKeyLenConstDigestLen<KEY_LEN, OUT_LEN>>
impl<const KEY_LEN: usize, const OUT_LEN: usize> Blake2b<ConstKeyLenConstDigestLen<KEY_LEN, OUT_LEN>>
Sourceimpl<const KEY_LEN: usize, const OUT_LEN: usize> Blake2b<ConstKeyLenConstDigestLen<KEY_LEN, OUT_LEN>>
impl<const KEY_LEN: usize, const OUT_LEN: usize> Blake2b<ConstKeyLenConstDigestLen<KEY_LEN, OUT_LEN>>
Sourcepub fn reset_with_key(&mut self, key: &[u8; KEY_LEN])
pub fn reset_with_key(&mut self, key: &[u8; KEY_LEN])
Reset the hash state and update the key to the contents of key.
Sourceimpl<const KEY_LEN: usize> Blake2b<ConstKeyLen<KEY_LEN>>
impl<const KEY_LEN: usize> Blake2b<ConstKeyLen<KEY_LEN>>
Sourcepub fn reset_with_key(&mut self, key: &[u8; KEY_LEN])
pub fn reset_with_key(&mut self, key: &[u8; KEY_LEN])
Reset the hash state and update the key to the contents of key.